==> suir-component-mapper-3.12.0.tgz: package/esm/sub-form/sub-form.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React, { createElement } from 'react';
import PropTypes from 'prop-types';
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
import Header from "semantic-ui-react/dist/es/elements/Header/Header.js";

var SubForm = function SubForm(_ref) {
  var fields = _ref.fields,
      title = _ref.title,
      description = _ref.description,
      component = _ref.component,
      HeaderProps = _ref.HeaderProps,
      _ref$DescriptionProps = _ref.DescriptionProps,
      descriptionElement = _ref$DescriptionProps.element,
      DescriptionProps = _objectWithoutProperties(_ref$DescriptionProps, ["element"]),
      _ref$FormFieldsGridPr = _ref.FormFieldsGridProps,
      formFieldsGridElement = _ref$FormFieldsGridPr.element,
      FormFieldsGridProps = _objectWithoutProperties(_ref$FormFieldsGridPr, ["element"]),
      rest = _objectWithoutProperties(_ref, ["fields", "title", "description", "component", "HeaderProps", "DescriptionProps", "FormFieldsGridProps"]);

  var _useFormApi = useFormApi(),
      renderForm = _useFormApi.renderForm;

  return /*#__PURE__*/React.createElement("div", rest, title && /*#__PURE__*/React.createElement(Header, HeaderProps, title), description && createElement(descriptionElement || 'p', DescriptionProps, description), createElement(formFieldsGridElement || 'div', FormFieldsGridProps, renderForm(fields)));
};

SubForm.propTypes = {
  fields: PropTypes.oneOfType([PropTypes.object, PropTypes.array]).isRequired,
  title: PropTypes.node,
  description: PropTypes.node,
  component: PropTypes.any,
  HeaderProps: PropTypes.object,
  DescriptionProps: PropTypes.shape({
    element: PropTypes.string.isRequired
  }),
  FormFieldsGridProps: PropTypes.shape({
    element: PropTypes.string.isRequired
  })
};
SubForm.defaultProps = {
  HeaderProps: {},
  DescriptionProps: {
    element: 'p'
  },
  FormFieldsGridProps: {
    element: 'div'
  }
};
export default SubForm;

==> suir-component-mapper-3.15.0.tgz: package/esm/sub-form/sub-form.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["element"],
    _excluded2 = ["element"],
    _excluded3 = ["fields", "title", "description", "component", "HeaderProps", "DescriptionProps", "FormFieldsGridProps"];
import React, { createElement } from 'react';
import PropTypes from 'prop-types';
import useFormApi from "@data-driven-forms/react-form-renderer/use-form-api";
import Header from "semantic-ui-react/dist/es/elements/Header/Header.js";

var SubForm = function SubForm(_ref) {
  var fields = _ref.fields,
      title = _ref.title,
      description = _ref.description,
      component = _ref.component,
      HeaderProps = _ref.HeaderProps,
      _ref$DescriptionProps = _ref.DescriptionProps,
      descriptionElement = _ref$DescriptionProps.element,
      DescriptionProps = _objectWithoutProperties(_ref$DescriptionProps, _excluded),
      _ref$FormFieldsGridPr = _ref.FormFieldsGridProps,
      formFieldsGridElement = _ref$FormFieldsGridPr.element,
      FormFieldsGridProps = _objectWithoutProperties(_ref$FormFieldsGridPr, _excluded2),
      rest = _objectWithoutProperties(_ref, _excluded3);

  var _useFormApi = useFormApi(),
      renderForm = _useFormApi.renderForm;

  return /*#__PURE__*/React.createElement("div", rest, title && /*#__PURE__*/React.createElement(Header, HeaderProps, title), description && /*#__PURE__*/createElement(descriptionElement || 'p', DescriptionProps, description), /*#__PURE__*/createElement(formFieldsGridElement || 'div', FormFieldsGridProps, renderForm(fields)));
};

SubForm.propTypes = {
  fields: PropTypes.oneOfType([PropTypes.object, PropTypes.array]).isRequired,
  title: PropTypes.node,
  description: PropTypes.node,
  component: PropTypes.any,
  HeaderProps: PropTypes.object,
  DescriptionProps: PropTypes.shape({
    element: PropTypes.string.isRequired
  }),
  FormFieldsGridProps: PropTypes.shape({
    element: PropTypes.string.isRequired
  })
};
SubForm.defaultProps = {
  HeaderProps: {},
  DescriptionProps: {
    element: 'p'
  },
  FormFieldsGridProps: {
    element: 'div'
  }
};
export default SubForm;
